@@ -1,23 +1,13 @@
 # -*- coding: utf-8 -*-
 """These test the utils.py functions."""
-from __future__ import unicode_literals
 
 import pytest
 from hypothesis import example, given
 from hypothesis.strategies import integers, text
-from natsort.compat.py23 import NEWPY
 from natsort.ns_enum import NS_DUMB, ns
 from natsort.utils import input_string_transform_factory
 
 
-def lower(x):
-    """Call the appropriate lower method for the Python version."""
-    if NEWPY:
-        return x.casefold()
-    else:
-        return x.lower()
-
-
 def thousands_separated_int(n):
     """Insert thousands separators in an int."""
     new_int = ""
@@ -38,11 +28,11 @@ def test_input_string_transform_factory_is_no_op_for_no_alg_options(x):
 @pytest.mark.parametrize(
     "alg, example_func",
     [
-        (ns.IGNORECASE, lower),
+        (ns.IGNORECASE, lambda x: x.casefold()),
         (NS_DUMB, lambda x: x.swapcase()),
         (ns.LOWERCASEFIRST, lambda x: x.swapcase()),
         (NS_DUMB | ns.LOWERCASEFIRST, lambda x: x),  # No-op
-        (ns.IGNORECASE | ns.LOWERCASEFIRST, lambda x: lower(x.swapcase())),
+        (ns.IGNORECASE | ns.LOWERCASEFIRST, lambda x: x.swapcase().casefold()),
     ],
 )
 @given(x=text())
@@ -84,20 +74,6 @@ def test_input_string_transform_factory_handles_us_locale(x, expected):
     assert input_string_transform_func(x) == expected
 
 
-@pytest.mark.parametrize(
-    "x, expected",
-    [
-        ("12.543.642642,5345.34980", "12543.642642,5345.34980"),
-        ("12.59443.642.642,53.4534980", "12.59443.642642,53.4534980"),  # No change
-        ("12543.642.642,5.34534980", "12543.642642,5.34534980"),
-    ],
-)
-@pytest.mark.usefixtures("with_locale_de_de")
-def test_input_string_transform_factory_handles_de_locale(x, expected):
-    input_string_transform_func = input_string_transform_factory(ns.LOCALE)
-    assert input_string_transform_func(x) == expected
-
-
 @pytest.mark.parametrize(
     "alg, expected",
     [
