@@ -3,13 +3,11 @@
 Here are a collection of examples of how this module can be used.
 See the README or the natsort homepage for more details.
 """
-from __future__ import print_function, unicode_literals
 
 from operator import itemgetter
 
 import pytest
 from natsort import as_utf8, natsorted, ns
-from natsort.compat.py23 import PY_VERSION
 from pytest import raises
 
 
@@ -101,7 +99,6 @@ def test_natsorted_handles_nan(alg, expected, slc):
     assert natsorted(given, alg=alg)[slc] == expected[slc]
 
 
-@pytest.mark.skipif(PY_VERSION < 3.0, reason="error is only raised on Python 3")
 def test_natsorted_with_mixed_bytes_and_str_input_raises_type_error():
     with raises(TypeError, match="bytes"):
         natsorted(["ä", b"b"])
@@ -135,12 +132,14 @@ def test_natsorted_returns_list_in_reversed_order_with_reverse_option(float_list
 def test_natsorted_handles_filesystem_paths():
     given = [
         "/p/Folder (10)/file.tar.gz",
-        "/p/Folder/file.tar.gz",
         "/p/Folder (1)/file (1).tar.gz",
+        "/p/Folder/file.x1.9.tar.gz",
         "/p/Folder (1)/file.tar.gz",
+        "/p/Folder/file.x1.10.tar.gz",
     ]
     expected_correct = [
-        "/p/Folder/file.tar.gz",
+        "/p/Folder/file.x1.10.tar.gz",
+        "/p/Folder/file.x1.9.tar.gz",
         "/p/Folder (1)/file.tar.gz",
         "/p/Folder (1)/file (1).tar.gz",
         "/p/Folder (10)/file.tar.gz",
@@ -149,12 +148,13 @@ def test_natsorted_handles_filesystem_paths():
         "/p/Folder (1)/file (1).tar.gz",
         "/p/Folder (1)/file.tar.gz",
         "/p/Folder (10)/file.tar.gz",
-        "/p/Folder/file.tar.gz",
+        "/p/Folder/file.x1.10.tar.gz",
+        "/p/Folder/file.x1.9.tar.gz",
     ]
     # Is incorrect by default.
-    assert natsorted(given) == expected_incorrect
+    assert natsorted(given, alg=ns.FLOAT) == expected_incorrect
     # Need ns.PATH to make it correct.
-    assert natsorted(given, alg=ns.PATH) == expected_correct
+    assert natsorted(given, alg=ns.FLOAT | ns.PATH) == expected_correct
 
 
 def test_natsorted_handles_numbers_and_filesystem_paths_simultaneously():
@@ -219,14 +219,6 @@ def test_natsorted_can_sort_locale_specific_numbers_de():
     assert natsorted(given, alg=ns.LOCALE | ns.F) == expected
 
 
-@pytest.mark.usefixtures("with_locale_de_de")
-def test_natsorted_locale_bug_regression_test_109():
-    # https://github.com/SethMMorton/natsort/issues/109
-    given = ["462166", "461761"]
-    expected = ["461761", "462166"]
-    assert natsorted(given, alg=ns.LOCALE) == expected
-
-
 @pytest.mark.parametrize(
     "alg, expected",
     [
